import _extends from "@babel/runtime/helpers/extends";
import React from 'react';
import PropTypes from 'prop-types';
import DualListSelectCommon from '@data-driven-forms/common/dual-list-select';
import { Menu } from "@blueprintjs/core/lib/esm/components/menu/menu.js";
import { MenuItem } from "@blueprintjs/core/lib/esm/components/menu/menuItem.js";
import { ButtonGroup } from "@blueprintjs/core/lib/esm/components/button/buttonGroup.js";
import { Button } from "@blueprintjs/core/lib/esm/components/button/buttons.js";
import { ControlGroup } from "@blueprintjs/core/lib/esm/components/forms/controlGroup.js";
import { InputGroup } from "@blueprintjs/core/lib/esm/components/forms/inputGroup.js";
import clsx from 'clsx';
import { createUseStyles } from "react-jss/dist/react-jss.esm.js";
import { FormGroupInternal } from '../form-group/form-group';
var useStyles = createUseStyles({
  menu: {
    height: '80%',
    overflow: 'auto'
  },
  buttonGroup: {
    justifyContent: 'center'
  },
  wrapper: {
    display: 'flex',
    justifyContent: 'space-evenly',
    minHeight: 250
  },
  '@media (max-width: 768px)': {
    wrapper: {
      flexDirection: 'column'
    }
  }
});

var List = function List(_ref) {
  var _ref$value = _ref.value,
      value = _ref$value === void 0 ? [] : _ref$value,
      optionClick = _ref.optionClick,
      noOptionsTitle = _ref.noOptionsTitle,
      filterValue = _ref.filterValue,
      filterValueText = _ref.filterValueText,
      selectedValues = _ref.selectedValues,
      _ref$MenuProps = _ref.MenuProps,
      MenuProps = _ref$MenuProps === void 0 ? {} : _ref$MenuProps,
      _ref$MenuItemProps = _ref.MenuItemProps,
      MenuItemProps = _ref$MenuItemProps === void 0 ? {} : _ref$MenuItemProps;

  var _useStyles = useStyles(),
      menu = _useStyles.menu;

  return /*#__PURE__*/React.createElement(Menu, _extends({}, MenuProps, {
    className: clsx('bp4-elevation-1', menu, MenuProps.className)
  }), value.length < 1 && /*#__PURE__*/React.createElement(MenuItem, _extends({
    text: filterValue ? filterValueText : noOptionsTitle,
    disabled: true
  }, MenuItemProps)), value.length > 0 && value.map(function (_ref2) {
    var value = _ref2.value,
        label = _ref2.label,
        ItemMenuItemProps = _ref2.MenuItemProps;
    return /*#__PURE__*/React.createElement(MenuItem, _extends({
      onClick: function onClick(e) {
        return optionClick(e, value);
      },
      key: value,
      active: selectedValues.includes(value),
      text: label
    }, MenuItemProps, ItemMenuItemProps));
  }));
};

List.propTypes = {
  value: PropTypes.arrayOf(PropTypes.shape({
    value: PropTypes.string.isRequired,
    label: PropTypes.string.isRequired
  })),
  optionClick: PropTypes.func.isRequired,
  noOptionsTitle: PropTypes.node,
  filterValue: PropTypes.string,
  filterValueText: PropTypes.node,
  selectedValues: PropTypes.array,
  checkboxVariant: PropTypes.bool,
  MenuProps: PropTypes.object,
  MenuItemProps: PropTypes.object
};

var Toolbar = function Toolbar(_ref3) {
  var sortTitle = _ref3.sortTitle,
      onFilter = _ref3.onFilter,
      onSort = _ref3.onSort,
      sortDirection = _ref3.sortDirection,
      value = _ref3.value,
      placeholder = _ref3.placeholder,
      _ref3$ControlGroupPro = _ref3.ControlGroupProps,
      ControlGroupProps = _ref3$ControlGroupPro === void 0 ? {} : _ref3$ControlGroupPro,
      _ref3$InputGroupProps = _ref3.InputGroupProps,
      InputGroupProps = _ref3$InputGroupProps === void 0 ? {} : _ref3$InputGroupProps,
      _ref3$ButtonProps = _ref3.ButtonProps,
      ButtonProps = _ref3$ButtonProps === void 0 ? {} : _ref3$ButtonProps;
  return /*#__PURE__*/React.createElement(ControlGroup, ControlGroupProps, /*#__PURE__*/React.createElement(InputGroup, _extends({
    placeholder: placeholder,
    onChange: function onChange(e) {
      return onFilter(e.target.value);
    },
    value: value
  }, InputGroupProps)), /*#__PURE__*/React.createElement(Button, _extends({
    icon: sortDirection ? 'sort-desc' : 'sort-asc',
    title: sortTitle,
    onClick: onSort
  }, ButtonProps)));
};

Toolbar.propTypes = {
  sortTitle: PropTypes.node,
  onFilter: PropTypes.func.isRequired,
  onSort: PropTypes.func.isRequired,
  sortDirection: PropTypes.bool,
  value: PropTypes.string,
  placeholder: PropTypes.string,
  ControlGroupProps: PropTypes.object,
  InputGroupProps: PropTypes.object,
  ButtonProps: PropTypes.object
};

var DualListInternal = function DualListInternal(_ref4) {
  var _ref4$allToRight = _ref4.allToRight,
      allToRight = _ref4$allToRight === void 0 ? true : _ref4$allToRight,
      _ref4$allToLeft = _ref4.allToLeft,
      allToLeft = _ref4$allToLeft === void 0 ? true : _ref4$allToLeft,
      _ref4$leftTitle = _ref4.leftTitle,
      leftTitle = _ref4$leftTitle === void 0 ? 'Options' : _ref4$leftTitle,
      _ref4$moveAllLeftTitl = _ref4.moveAllLeftTitle,
      moveAllLeftTitle = _ref4$moveAllLeftTitl === void 0 ? 'Move all to left' : _ref4$moveAllLeftTitl,
      _ref4$moveAllRightTit = _ref4.moveAllRightTitle,
      moveAllRightTitle = _ref4$moveAllRightTit === void 0 ? 'Move all to right' : _ref4$moveAllRightTit,
      _ref4$moveRightTitle = _ref4.moveRightTitle,
      moveRightTitle = _ref4$moveRightTitle === void 0 ? 'Move selected to right' : _ref4$moveRightTitle,
      _ref4$moveLeftTitle = _ref4.moveLeftTitle,
      moveLeftTitle = _ref4$moveLeftTitle === void 0 ? 'Move selected to left' : _ref4$moveLeftTitle,
      _ref4$rightTitle = _ref4.rightTitle,
      rightTitle = _ref4$rightTitle === void 0 ? 'Selected' : _ref4$rightTitle,
      _ref4$noValueTitle = _ref4.noValueTitle,
      noValueTitle = _ref4$noValueTitle === void 0 ? 'No selected' : _ref4$noValueTitle,
      _ref4$noOptionsTitle = _ref4.noOptionsTitle,
      noOptionsTitle = _ref4$noOptionsTitle === void 0 ? 'No available options' : _ref4$noOptionsTitle,
      _ref4$filterOptionsTi = _ref4.filterOptionsTitle,
      filterOptionsTitle = _ref4$filterOptionsTi === void 0 ? 'Filter options' : _ref4$filterOptionsTi,
      _ref4$filterValueTitl = _ref4.filterValueTitle,
      filterValueTitle = _ref4$filterValueTitl === void 0 ? 'Filter selected value' : _ref4$filterValueTitl,
      _ref4$filterValueText = _ref4.filterValueText,
      filterValueText = _ref4$filterValueText === void 0 ? 'Remove your filter to see all selected' : _ref4$filterValueText,
      _ref4$filterOptionsTe = _ref4.filterOptionsText,
      filterOptionsText = _ref4$filterOptionsTe === void 0 ? 'Remove your filter to see all options' : _ref4$filterOptionsTe,
      state = _ref4.state,
      sortOptions = _ref4.sortOptions,
      filterOptions = _ref4.filterOptions,
      handleOptionsClick = _ref4.handleOptionsClick,
      leftValues = _ref4.leftValues,
      handleMoveRight = _ref4.handleMoveRight,
      handleMoveLeft = _ref4.handleMoveLeft,
      handleClearLeftValues = _ref4.handleClearLeftValues,
      handleClearRightValues = _ref4.handleClearRightValues,
      sortValues = _ref4.sortValues,
      filterValues = _ref4.filterValues,
      rightValues = _ref4.rightValues,
      handleValuesClick = _ref4.handleValuesClick,
      _ref4$WrapperProps = _ref4.WrapperProps,
      WrapperProps = _ref4$WrapperProps === void 0 ? {} : _ref4$WrapperProps,
      _ref4$LeftWrapperProp = _ref4.LeftWrapperProps,
      LeftWrapperProps = _ref4$LeftWrapperProp === void 0 ? {} : _ref4$LeftWrapperProp,
      _ref4$RightWrapperPro = _ref4.RightWrapperProps,
      RightWrapperProps = _ref4$RightWrapperPro === void 0 ? {} : _ref4$RightWrapperPro,
      _ref4$ButtonGroupProp = _ref4.ButtonGroupProps,
      ButtonGroupProps = _ref4$ButtonGroupProp === void 0 ? {} : _ref4$ButtonGroupProp,
      _ref4$ToRightButtonPr = _ref4.ToRightButtonProps,
      ToRightButtonProps = _ref4$ToRightButtonPr === void 0 ? {} : _ref4$ToRightButtonPr,
      _ref4$AllToRightButto = _ref4.AllToRightButtonProps,
      AllToRightButtonProps = _ref4$AllToRightButto === void 0 ? {} : _ref4$AllToRightButto,
      _ref4$AllToLeftButton = _ref4.AllToLeftButtonProps,
      AllToLeftButtonProps = _ref4$AllToLeftButton === void 0 ? {} : _ref4$AllToLeftButton,
      _ref4$ToLeftButtonPro = _ref4.ToLeftButtonProps,
      ToLeftButtonProps = _ref4$ToLeftButtonPro === void 0 ? {} : _ref4$ToLeftButtonPro,
      _ref4$LeftControlGrou = _ref4.LeftControlGroupProps,
      LeftControlGroupProps = _ref4$LeftControlGrou === void 0 ? {} : _ref4$LeftControlGrou,
      _ref4$LeftInputGroupP = _ref4.LeftInputGroupProps,
      LeftInputGroupProps = _ref4$LeftInputGroupP === void 0 ? {} : _ref4$LeftInputGroupP,
      _ref4$LeftButtonProps = _ref4.LeftButtonProps,
      LeftButtonProps = _ref4$LeftButtonProps === void 0 ? {} : _ref4$LeftButtonProps,
      _ref4$RightControlGro = _ref4.RightControlGroupProps,
      RightControlGroupProps = _ref4$RightControlGro === void 0 ? {} : _ref4$RightControlGro,
      _ref4$RightInputGroup = _ref4.RightInputGroupProps,
      RightInputGroupProps = _ref4$RightInputGroup === void 0 ? {} : _ref4$RightInputGroup,
      _ref4$RightButtonProp = _ref4.RightButtonProps,
      RightButtonProps = _ref4$RightButtonProp === void 0 ? {} : _ref4$RightButtonProp,
      _ref4$LeftMenuProps = _ref4.LeftMenuProps,
      LeftMenuProps = _ref4$LeftMenuProps === void 0 ? {} : _ref4$LeftMenuProps,
      _ref4$LeftMenuItemPro = _ref4.LeftMenuItemProps,
      LeftMenuItemProps = _ref4$LeftMenuItemPro === void 0 ? {} : _ref4$LeftMenuItemPro,
      _ref4$RightMenuProps = _ref4.RightMenuProps,
      RightMenuProps = _ref4$RightMenuProps === void 0 ? {} : _ref4$RightMenuProps,
      _ref4$RightMenuItemPr = _ref4.RightMenuItemProps,
      RightMenuItemProps = _ref4$RightMenuItemPr === void 0 ? {} : _ref4$RightMenuItemPr,
      _ref4$leftSortTitle = _ref4.leftSortTitle,
      leftSortTitle = _ref4$leftSortTitle === void 0 ? 'Sort options' : _ref4$leftSortTitle,
      _ref4$rightSortTitle = _ref4.rightSortTitle,
      rightSortTitle = _ref4$rightSortTitle === void 0 ? 'Sort value' : _ref4$rightSortTitle;

  var _useStyles2 = useStyles(),
      buttonGroup = _useStyles2.buttonGroup,
      wrapper = _useStyles2.wrapper;

  return /*#__PURE__*/React.createElement("div", _extends({}, WrapperProps, {
    className: clsx(wrapper, WrapperProps.className)
  }), /*#__PURE__*/React.createElement("div", LeftWrapperProps, leftTitle, /*#__PURE__*/React.createElement(Toolbar, {
    sortDirection: state.sortLeftDesc,
    onSort: sortOptions,
    onFilter: filterOptions,
    value: state.filterOptions,
    placeholder: filterOptionsTitle,
    ControlGroupProps: LeftControlGroupProps,
    InputGroupProps: LeftInputGroupProps,
    ButtonProps: LeftButtonProps,
    sortTitle: leftSortTitle
  }), /*#__PURE__*/React.createElement(List, {
    optionClick: handleOptionsClick,
    value: leftValues,
    noOptionsTitle: noOptionsTitle,
    filterValue: state.filterOptions,
    filterValueText: filterOptionsText,
    selectedValues: state.selectedLeftValues,
    MenuProps: LeftMenuProps,
    MenuItemProps: LeftMenuItemProps
  })), /*#__PURE__*/React.createElement(ButtonGroup, _extends({
    vertical: true,
    alignText: "center"
  }, ButtonGroupProps, {
    className: clsx(buttonGroup, ButtonGroupProps.className)
  }), /*#__PURE__*/React.createElement(Button, _extends({
    disabled: state.selectedLeftValues.length === 0,
    onClick: handleMoveRight,
    title: moveRightTitle,
    icon: "chevron-right"
  }, ToRightButtonProps)), allToRight && /*#__PURE__*/React.createElement(Button, _extends({
    disabled: leftValues.length === 0,
    onClick: handleClearLeftValues,
    title: moveAllRightTitle,
    icon: "double-chevron-right"
  }, AllToRightButtonProps)), allToLeft && /*#__PURE__*/React.createElement(Button, _extends({
    disabled: rightValues.length === 0,
    onClick: handleClearRightValues,
    title: moveAllLeftTitle,
    icon: "double-chevron-left"
  }, AllToLeftButtonProps)), /*#__PURE__*/React.createElement(Button, _extends({
    disabled: state.selectedRightValues.length === 0,
    onClick: handleMoveLeft,
    title: moveLeftTitle,
    icon: "chevron-left"
  }, ToLeftButtonProps))), /*#__PURE__*/React.createElement("div", RightWrapperProps, rightTitle, /*#__PURE__*/React.createElement(Toolbar, {
    sortDirection: state.sortRightDesc,
    onSort: sortValues,
    onFilter: filterValues,
    value: state.filterValue,
    placeholder: filterValueTitle,
    ControlGroupProps: RightControlGroupProps,
    InputGroupProps: RightInputGroupProps,
    ButtonProps: RightButtonProps,
    sortTitle: rightSortTitle
  }), /*#__PURE__*/React.createElement(List, {
    optionClick: handleValuesClick,
    value: rightValues,
    noOptionsTitle: noValueTitle,
    filterValue: state.filterValue,
    filterValueText: filterValueText,
    selectedValues: state.selectedRightValues,
    MenuProps: RightMenuProps,
    MenuItemProps: RightMenuItemProps
  })));
};

DualListInternal.propTypes = {
  leftTitle: PropTypes.node,
  rightTitle: PropTypes.node,
  moveLeftTitle: PropTypes.node,
  moveRightTitle: PropTypes.node,
  allToLeft: PropTypes.bool,
  allToRight: PropTypes.bool,
  validateOnMount: PropTypes.bool,
  moveAllLeftTitle: PropTypes.node,
  moveAllRightTitle: PropTypes.node,
  noValueTitle: PropTypes.node,
  noOptionsTitle: PropTypes.node,
  filterOptionsTitle: PropTypes.node,
  filterValueTitle: PropTypes.node,
  filterValueText: PropTypes.node,
  filterOptionsText: PropTypes.node,
  state: PropTypes.object,
  sortOptions: PropTypes.func,
  filterOptions: PropTypes.func,
  handleOptionsClick: PropTypes.func,
  leftValues: PropTypes.array,
  handleMoveRight: PropTypes.func,
  handleMoveLeft: PropTypes.func,
  handleClearLeftValues: PropTypes.func,
  handleClearRightValues: PropTypes.func,
  sortValues: PropTypes.func,
  filterValues: PropTypes.func,
  rightValues: PropTypes.array,
  handleValuesClick: PropTypes.func,
  WrapperProps: PropTypes.object,
  LeftWrapperProps: PropTypes.object,
  RightWrapperProps: PropTypes.object,
  ButtonGroupProps: PropTypes.object,
  ToRightButtonProps: PropTypes.object,
  AllToRightButtonProps: PropTypes.object,
  AllToLeftButtonProps: PropTypes.object,
  ToLeftButtonProps: PropTypes.object,
  LeftControlGroupProps: PropTypes.object,
  LeftInputGroupProps: PropTypes.object,
  LeftButtonProps: PropTypes.object,
  RightControlGroupProps: PropTypes.object,
  RightInputGroupProps: PropTypes.object,
  RightButtonProps: PropTypes.object,
  LeftMenuProps: PropTypes.object,
  LeftMenuItemProps: PropTypes.object,
  RightMenuProps: PropTypes.object,
  RightMenuItemProps: PropTypes.object,
  leftSortTitle: PropTypes.string,
  rightSortTitle: PropTypes.string
};

var DualListWrapper = function DualListWrapper(props) {
  return /*#__PURE__*/React.createElement(FormGroupInternal, _extends({}, props, {
    Component: DualListInternal
  }));
};

var DualListSelect = function DualListSelect(props) {
  return /*#__PURE__*/React.createElement(DualListSelectCommon, _extends({}, props, {
    DualListSelect: DualListWrapper
  }));
};

export default DualListSelect;